@@ -33,16 +33,7 @@
 #include <math.h>
 #include <float.h>
 
-#ifdef HAVE_PROJ_H
-/* Work around broken check in proj.h:
- * https://github.com/OSGeo/PROJ/issues/1523
- */
-# ifndef PROJ_H
-#  include <proj.h>
-# endif
-#endif
-#define ACCEPT_USE_OF_DEPRECATED_PROJ_API_H 1
-#include <proj_api.h>
+#include <proj.h>
 
 #include "img_hosted.h"
 #include "useful.h"
@@ -338,15 +329,19 @@ typedef struct Settings {
    const reading *ordering;
    int begin_lineno; /* 0 means no block started in this file */
    int flags;
-   projPJ proj;
+   char* proj_str;
    /* Location at which we calculate the declination if
-    * z[Q_DECLINATION] == HUGE_REAL. */
-   real dec_x, dec_y, dec_z;
-   /* Cached auto-declination, or HUGE_REAL for no cached value.  Only
-    * meaningful if date1 != -1.
+    * z[Q_DECLINATION] == HUGE_REAL.
+    *
+    * Latitude and longitude are in radians; altitude is in metres above the
+    * ellipsoid.
+    */
+   real dec_lat, dec_lon, dec_alt;
+   /* Cached auto-declination in radians, or HUGE_REAL for no cached value.
+    * Only meaningful if date1 != -1.
     */
    real declination;
-   /* Grid convergence. */
+   /* Grid convergence in radians. */
    real convergence;
    meta_data * meta;
 } settings;
@@ -357,8 +352,8 @@ extern prefix *root;
 extern prefix *anon_list;
 extern node *stnlist;
 extern unsigned long optimize;
-extern projPJ proj_out;
 extern char * proj_str_out;
+extern PJ * pj_cached;
 
 extern char *survey_title;
 extern int survey_title_len;
