@@ -1,6 +1,6 @@
 /* extend.c
  * Produce an extended elevation
- * Copyright (C) 1995-2002,2005,2010,2011,2013,2014,2016 Olly Betts
+ * Copyright (C) 1995-2002,2005,2010,2011,2013,2014,2016,2017 Olly Betts
  * Copyright (C) 2004,2005 John Pybus
  *
  * This program is free software; you can redistribute it and/or modify
@@ -45,6 +45,11 @@ typedef struct stn {
    const struct stn *next;
 } stn;
 
+typedef struct splay {
+   struct POINT *pt;
+   struct splay *next;
+} splay;
+
 typedef struct POINT {
    img_point p;
    double X;
@@ -53,6 +58,7 @@ typedef struct POINT {
    char dir;
    char fDone;
    char fBroken;
+   splay *splays;
    struct POINT *next;
 } point;
 
@@ -75,7 +81,7 @@ typedef struct LEG {
 #define ERIGHT 0x02
 #define ESWAP  0x04
 
-static point headpoint = {{0, 0, 0}, 0, NULL, 0, 0, 0, 0, NULL};
+static point headpoint = {{0, 0, 0}, 0, NULL, 0, 0, 0, 0, NULL, NULL};
 
 static leg headleg = {NULL, NULL, NULL, 0, 0, 0, 0, NULL};
 
@@ -83,7 +89,7 @@ static img *pimg_out;
 
 static int show_breaks = 0;
 
-static void do_stn(point *, double, const char *, int, int);
+static void do_stn(point *, double, const char *, int, int, double, double);
 
 typedef struct pfx {
    const char *label;
@@ -133,6 +139,7 @@ find_point(const img_point *pt)
    p->dir = 0;
    p->fDone = 0;
    p->fBroken = 0;
+   p->splays = NULL;
    p->next = headpoint.next;
    headpoint.next = p;
    return p;
@@ -538,7 +545,7 @@ main(int argc, char **argv)
    const char *survey = NULL;
    const char *specfile = NULL;
    img *pimg;
-   int have_xsect = 0;
+   int xsections = 0, splays = 0;
 
    msg_init(argv);
 
@@ -598,8 +605,13 @@ main(int argc, char **argv)
 	    break;
 	 }
 	 to = find_point(&pt);
-	 if (!(pimg->flags & (img_FLAG_SURFACE|img_FLAG_SPLAY)))
-	    add_leg(fr, to, pimg->label, pimg->flags);
+	 if (!(pimg->flags & img_FLAG_SURFACE)) {
+	    if (pimg->flags & img_FLAG_SPLAY) {
+	       ++splays;
+	    } else {
+	       add_leg(fr, to, pimg->label, pimg->flags);
+	    }
+	 }
 	 fr = to;
 	 break;
       case img_LABEL:
@@ -611,11 +623,56 @@ main(int argc, char **argv)
 	 fatalerror(img_error2msg(img_error()), fnm_in);
 	 break;
       case img_XSECT:
-	 have_xsect = 1;
+      case img_XSECT_END:
+	 ++xsections;
 	 break;
       }
    } while (result != img_STOP);
 
+   if (splays) {
+      img_rewind(pimg);
+      fr = NULL;
+      do {
+	 result = img_read_item(pimg, &pt);
+	 switch (result) {
+	 case img_MOVE:
+	    fr = find_point(&pt);
+	    break;
+	 case img_LINE:
+	    if (!fr) {
+	       result = img_BAD;
+	       break;
+	    }
+	    to = find_point(&pt);
+	    if (!(pimg->flags & img_FLAG_SURFACE)) {
+	       if (pimg->flags & img_FLAG_SPLAY) {
+		  splay *sp = osmalloc(ossizeof(splay));
+		  --splays;
+		  if (fr->order) {
+		     if (to->order == 0) {
+			sp->pt = to;
+			sp->next = fr->splays;
+			fr->splays = sp;
+		     } else {
+			printf("Splay without a dead end from %s to %s\n", fr->stns->label, to->stns->label);
+			osfree(sp);
+		     }
+		  } else if (to->order) {
+		     sp->pt = fr;
+		     sp->next = to->splays;
+		     to->splays = sp;
+		  } else {
+		     printf("Isolated splay from %s to %s\n", fr->stns->label, to->stns->label);
+		     osfree(sp);
+		  }
+	       }
+	    }
+	    fr = to;
+	    break;
+	 }
+      } while (splays && result != img_STOP);
+   }
+
    desc = osstrdup(pimg->title);
 
    if (specfile) {
@@ -651,9 +708,9 @@ main(int argc, char **argv)
    pimg_out = img_open_write(fnm_out, desc, img_FFLAG_EXTENDED);
 
    /* Only does single connected component currently. */
-   do_stn(start, 0.0, NULL, ERIGHT, 0);
+   do_stn(start, 0.0, NULL, ERIGHT, 0, 0.0, 0.0);
 
-   if (have_xsect) {
+   if (xsections) {
       img_rewind(pimg);
       /* Read ahead on pimg before writing pimg_out so we find out if an
        * img_XSECT_END comes next. */
@@ -661,14 +718,15 @@ main(int argc, char **argv)
       int flags = 0;
       do {
 	 result = img_read_item(pimg, &pt);
-	 if (result == img_XSECT || result == img_XSECT_END) {
-	    if (label) {
-	       if (result == img_XSECT_END)
-		  flags |= img_XFLAG_END;
-	       img_write_item(pimg_out, img_XSECT, flags, label, 0, 0, 0);
-	       osfree(label);
-	       label = NULL;
-	    }
+	 if (result != img_XSECT && result != img_XSECT_END)
+	    continue;
+	 --xsections;
+	 if (label) {
+	    if (result == img_XSECT_END)
+	       flags |= img_XFLAG_END;
+	    img_write_item(pimg_out, img_XSECT, flags, label, 0, 0, 0);
+	    osfree(label);
+	    label = NULL;
 	 }
 	 if (result == img_XSECT) {
 	    label = osstrdup(pimg->label);
@@ -678,7 +736,7 @@ main(int argc, char **argv)
 	    pimg_out->u = pimg->u;
 	    pimg_out->d = pimg->d;
 	 }
-      } while (result != img_STOP);
+      } while (xsections && result != img_STOP);
    }
 
    (void)img_close(pimg);
@@ -700,17 +758,61 @@ static int adjust_direction(int dir, int by) {
 }
 
 static void
-do_stn(point *p, double X, const char *prefix, int dir, int labOnly)
+do_splays(point *p, double X, int dir, double tdx, double tdy)
+{
+   const splay *sp;
+   double a;
+   double C, S;
+
+   if (!p->splays) return;
+
+   if (tdx == 0 && tdy == 0) {
+       /* Two adjacent plumbs, or a pair of legs that exactly cancel. */
+       return;
+   }
+
+   /* Bearing in radians. */
+   a = atan2(tdx, tdy);
+   if (dir == ELEFT) {
+       a = -M_PI_2 - a;
+   } else {
+       a = M_PI_2 - a;
+   }
+   C = cos(a);
+   S = sin(a);
+   for (sp = p->splays; sp; sp = sp->next) {
+      double x = X;
+      double z = p->p.z;
+      img_write_item(pimg_out, img_MOVE, 0, NULL, x, 0, z);
+
+      double dx = sp->pt->p.x - p->p.x;
+      double dy = sp->pt->p.y - p->p.y;
+      double dz = sp->pt->p.z - p->p.z;
+
+      double tmp = dx * C + dy * S;
+      dy = dy * C - dx * S;
+      dx = tmp;
+
+      img_write_item(pimg_out, img_LINE, img_FLAG_SPLAY, NULL, x + dx, dy, z + dz);
+   }
+   p->splays = NULL;
+}
+
+static void
+do_stn(point *p, double X, const char *prefix, int dir, int labOnly,
+       double odx, double ody)
 {
    leg *l, *lp;
    double dX;
    const stn *s;
    int odir = dir;
    int try_all;
+   int order = p->order;
 
    for (s = p->stns; s; s = s->next) {
       img_write_item(pimg_out, img_LABEL, s->flags, s->label, X, 0, p->p.z);
    }
+
    if (show_breaks && p->X != HUGE_VAL && p->X != X) {
       /* Draw "surface" leg between broken stations. */
       img_write_item(pimg_out, img_MOVE, 0, NULL, p->X, 0, p->p.z);
@@ -721,6 +823,13 @@ do_stn(point *p, double X, const char *prefix, int dir, int labOnly)
       return;
    }
 
+
+   if (order == 0) {
+      /* We've reached a dead end. */
+      do_splays(p, X, dir, odx, ody);
+      return;
+   }
+
    /* It's better to follow legs along a survey, so make two passes and only
     * follow legs in the same survey for the first pass.
     */
@@ -737,37 +846,49 @@ do_stn(point *p, double X, const char *prefix, int dir, int labOnly)
 	 if (!try_all && l->prefix != prefix) {
 	    continue;
 	 }
+	 int break_flag;
+	 point *p2;
 	 if (l->to == p) {
-	    if (l->broken & BREAK_TO) continue;
-	    lp->next = l->next;
-	    /* adjust direction of extension if necessary */
-	    dir = adjust_direction(dir, l->to->dir);
-	    dir = adjust_direction(dir, l->dir);
-
-	    dX = hypot(l->fr->p.x - l->to->p.x, l->fr->p.y - l->to->p.y);
-	    if (dir == ELEFT) dX = -dX;
-	    img_write_item(pimg_out, img_MOVE, 0, NULL, X + dX, 0, l->fr->p.z);
-	    img_write_item(pimg_out, img_LINE, l->flags, l->prefix,
-			   X, 0, l->to->p.z);
-	    l->fDone = 1;
-	    do_stn(l->fr, X + dX, l->prefix, dir, (l->broken & BREAK_FR));
-	    l = lp;
+	    break_flag = BREAK_TO;
+	    p2 = l->fr;
 	 } else if (l->fr == p) {
-	    if (l->broken & BREAK_FR) continue;
-	    lp->next = l->next;
-	    /* adjust direction of extension if necessary */
-	    dir = adjust_direction(dir, l->fr->dir);
-	    dir = adjust_direction(dir, l->dir);
-
-	    dX = hypot(l->fr->p.x - l->to->p.x, l->fr->p.y - l->to->p.y);
-	    if (dir == ELEFT) dX = -dX;
-	    img_write_item(pimg_out, img_MOVE, 0, NULL, X, 0, l->fr->p.z);
-	    img_write_item(pimg_out, img_LINE, l->flags, l->prefix,
-			   X + dX, 0, l->to->p.z);
-	    l->fDone = 1;
-	    do_stn(l->to, X + dX, l->prefix, dir, (l->broken & BREAK_TO));
-	    l = lp;
+	    break_flag = BREAK_FR;
+	    p2 = l->to;
+	 } else {
+	    continue;
 	 }
+	 if (l->broken & break_flag) continue;
+	 lp->next = l->next;
+	 /* adjust direction of extension if necessary */
+	 dir = adjust_direction(dir, p->dir);
+	 dir = adjust_direction(dir, l->dir);
+
+	 double dx = p2->p.x - p->p.x;
+	 double dy = p2->p.y - p->p.y;
+	 dX = hypot(dx, dy);
+	 double X2 = X;
+	 if (dir == ELEFT) {
+	    X2 -= dX;
+	 } else {
+	    X2 += dX;
+	 }
+
+	 if (p->splays) {
+	    do_splays(p, X, dir, odx + dx, ody + dy);
+	 }
+
+	 img_write_item(pimg_out, img_MOVE, 0, NULL, X, 0, p->p.z);
+	 img_write_item(pimg_out, img_LINE, l->flags, l->prefix,
+			X2, 0, p2->p.z);
+
+	 /* We arrive at p2 via a leg, so that's one down right away. */
+	 --p2->order;
+
+	 l->fDone = 1;
+	 /* l->broken doesn't have break_flag set as we checked that above. */
+	 do_stn(p2, X2, l->prefix, dir, l->broken, dx, dy);
+	 l = lp;
+	 if (--order == 0) return;
       }
    }
 }
